My Account - Telstra
Description: Stay connected overseas using your Next G Wireless Broadband Mobile service with broadband speeds in over 45 countries.
Keywords: Global roaming, international roaming, on the go, overseas, countries, outside Australia, coverage, international coverage, costs, costs outside Australia

Main content

##

#

# BIGPOND® BROADBAND

## My Account

### Enter your BigPond® or Telstra username.

### Login information

Username

eg you@bigpond.com, you@telstra.com, you@bigpond.net.au, you@yourdomain.com eg you@bigpond.com

Password*
Remember me Your username will be remembered on this computer, making logging in quicker and easier every time you visit. You'll only need to enter your password.

Forgotten your username or password?

Cancel and return to Telstra Media